@@ -1,6 +1,6 @@
 package Test::Routine::Meta::Attribute::Trait::AutoClear;
 {
-  $Test::Routine::Meta::Attribute::Trait::AutoClear::VERSION = '0.003';
+  $Test::Routine::Meta::Attribute::Trait::AutoClear::VERSION = '0.004';
 }
 # ABSTRACT: The attribute trait that does T::R::AutoClear's work
 use Moose::Role;
@@ -15,14 +15,17 @@ around set_initial_value => sub {
     my ($orig, $self, $instance, $value) = @_;
 
     $self->initial_value($value);
-    $self->$orig($instance, $value);
+    $self->$orig($instance, _unpack_initial_value($value, $instance));
 };
 
 around clear_value => sub {
     my ($clear_value, $self, $instance) = @_;
 
     if ($self->_has_initial_value) {
-        $self->set_value($instance, $self->initial_value);
+        $self->set_value(
+            $instance,
+            _unpack_initial_value($self->initial_value, $instance)
+        );
     }
     else {
         $self->$clear_value($instance);
@@ -36,6 +39,17 @@ sub _inline_clear_value {
     "\$_[0]->meta->get_attribute('$slot_name')->clear_value(\$_[0]);";
 }
 
+sub _unpack_initial_value {
+    my ($val, $instance) = @_;
+
+    if (blessed $val && $val->isa('Test::Routine::Meta::Builder')) {
+        return $val->($instance);
+    }
+    else {
+        return $val;
+    }
+}
+
 
 1;
 
@@ -49,7 +63,7 @@ Test::Routine::Meta::Attribute::Trait::AutoClear - The attribute trait that does
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 AUTHOR
 
